@@ -217,6 +217,9 @@ impl Sender{
         rpc_client::send_msg(self.server_url.clone(),
                              payload.into()).await
     }
+    pub async fn send_ignore_errors(&self, payload: Payload){
+        match self.send(payload).await{ _ => {} }
+    }
 }
 
 pub struct Api{
