@@ -1,8 +1,8 @@
 use serde::{Deserialize, Serialize};
 
-#[derive(Deserialize, Serialize, Debug)]
+#[derive(Deserialize, Serialize, Debug, Clone)]
 pub struct TinkoffApiKey{
     pub name: String,
     pub key: String,
-    pub time: f64,
+    pub time: i64,
 }
